==> openGion6.9.9.0_dev.zip: uap/webapps/ge/db/HSQLDB/sql/install/01_TABLE/GE39S.sql <==
/****************************************************************************/
/* GE39 ( ﾌｧｲﾙ管理ﾃｰﾌﾞﾙ )                                                   */
/*                                                                          */
/* Created : 2018/03/29 14:26:15                                            */
/****************************************************************************/

CREATE TABLE GE39 (
   UNIQ_ID      VARCHAR  (   10 )                   NOT NULL            /*  10 UNIQ番号     */
 , SEQNO        INTEGER                 DEFAULT 0   NOT NULL            /*  20 表示順       */
 , SYSTEM_ID    VARCHAR  (   10 )                   NOT NULL            /*  30 ｼｽﾃﾑID       */
 , SYFILE       VARCHAR  (  100 )                   NOT NULL            /*  40 ﾌｧｲﾙ種別     */
 , REF_KEY      VARCHAR  (  100 )                   NOT NULL            /*  50 関連ｷｰ       */
 , SUFFIX       VARCHAR  (   10 )                                       /*  60 拡張子       */
 , SYNAME       VARCHAR  (  200 )                                       /*  70 種別名称     */
 , SAVE_FOLDER  VARCHAR  (  300 )                                       /*  80 保管ﾌｫﾙﾀﾞ    */
 , FILE_URL     VARCHAR  (  300 )                                       /*  90 ﾌｧｲﾙURL      */
 , ICON_URL     VARCHAR  (  300 )                                       /* 100 ｱｲｺﾝURL      */
 , ROLES        VARCHAR  (  500 )                                       /* 110 ﾛｰﾙｽﾞ        */
 , SU_LMT       INTEGER                 DEFAULT 0   NOT NULL            /* 120 閲覧制限数   */
 , DY_LMT       INTEGER                 DEFAULT 0   NOT NULL            /* 130 閲覧期日     */
 , FGANGO       VARCHAR  (    1 )       DEFAULT '0' NOT NULL            /* 140 暗号化FG     */
 , FGZIP        VARCHAR  (    1 )       DEFAULT '0' NOT NULL            /* 150 圧縮FG       */
 , FILE_NAME    VARCHAR  (  500 )                                       /* 160 ﾌｧｲﾙ名称     */
 , CONTENTS     VARCHAR  ( 4000 )                                       /* 170 内容         */
 , FG_NEW       VARCHAR  (    1 )       DEFAULT '1' NOT NULL            /* 180 最新FG       */
 , SIZE_FILE    INTEGER                 DEFAULT 0   NOT NULL            /* 190 ﾌｧｲﾙｻｲｽﾞ     */
 , DYFILESET    VARCHAR  (   14 )                                       /* 200 ﾌｧｲﾙ登録日時 */
 , USRTOROKU    VARCHAR  (   10 )                                       /* 210 ﾌｧｲﾙ登録者   */
 , SETGUIID     VARCHAR  (   10 )                                       /* 220 登録画面ID   */
 , FGKOSHIN     VARCHAR  (    1 )       DEFAULT '1'                     /* 230 変更許可FG   */
 , FGKOKAI      VARCHAR  (    1 )       DEFAULT '1'                     /* 240 公開許可FG   */
 , SRCHKEY1     VARCHAR  (  500 )                                       /* 250 検索ｷｰ1      */
 , SRCHKEY2     VARCHAR  (  500 )                                       /* 270 検索ｷｰ2      */
 , SRCHKEY3     VARCHAR  (  500 )                                       /* 280 検索ｷｰ3      */
 , SRCHKEY4     VARCHAR  (  500 )                                       /* 290 検索ｷｰ4      */
 , SRCHKEY5     VARCHAR  (  500 )                                       /* 300 検索ｷｰ5      */
 , SRCHKEY6     VARCHAR  (  500 )                                       /* 310 検索ｷｰ6      */
 , SRCHKEY7     VARCHAR  (  500 )                                       /* 320 検索ｷｰ7      */
 , SRCHKEY8     VARCHAR  (  500 )                                       /* 330 検索ｷｰ8      */
 , SRCHKEY9     VARCHAR  (  500 )                                       /* 340 検索ｷｰ9      */
 , SRCHKEY10    VARCHAR  (  500 )                                       /* 350 検索ｷｰ10     */
 , UNIQ         IDENTITY                                                /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR  (    1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR  (   14 )                                       /* 820 登録日時     */
 , PGSET        VARCHAR  (   10 )                                       /* 830 作成PG       */
 , PGPSET       VARCHAR  (   10 )                                       /* 840 作成親PG     */
 , USRSET       VARCHAR  (   10 )                                       /* 850 作成社員     */
 , DYUPD        VARCHAR  (   14 )                                       /* 860 更新日時     */
 , PGUPD        VARCHAR  (   10 )                                       /* 870 更新PG       */
 , PGPUPD       VARCHAR  (   10 )                                       /* 880 更新親PG     */
 , USRUPD       VARCHAR  (   10 )                                       /* 890 更新者       */
);

==> openGion7.0.5.0_dev.zip: uap/webapps/ge/db/HSQLDB/sql/install/01_TABLE/GE39S.sql <==
/****************************************************************************/
/* GE39 ( ﾌｧｲﾙ管理ﾃｰﾌﾞﾙ )                                                   */
/*                                                                          */
/* Created : 2018/09/28 16:03:23                                            */
/****************************************************************************/

CREATE TABLE GE39 (
   UNIQ_ID      VARCHAR  (   10 )                   NOT NULL            /*  10 UNIQ番号     */
 , SEQNO        INTEGER                 DEFAULT 0   NOT NULL            /*  20 表示順       */
 , SYSTEM_ID    VARCHAR  (   10 )                   NOT NULL            /*  30 ｼｽﾃﾑID       */
 , SYFILE       VARCHAR  (  100 )                   NOT NULL            /*  40 ﾌｧｲﾙ種別     */
 , REF_KEY      VARCHAR  (  100 )                   NOT NULL            /*  50 関連ｷｰ       */
 , SUFFIX       VARCHAR  (   10 )                                       /*  60 拡張子       */
 , SYNAME       VARCHAR  (  200 )                                       /*  70 種別名称     */
 , SAVE_FOLDER  VARCHAR  (  300 )                                       /*  80 保管ﾌｫﾙﾀﾞ    */
 , FILE_URL     VARCHAR  (  300 )                                       /*  90 ﾌｧｲﾙURL      */
 , ICON_URL     VARCHAR  (  300 )                                       /* 100 ｱｲｺﾝURL      */
 , ROLES        VARCHAR  ( 2000 )                                       /* 110 ﾛｰﾙｽﾞ        */
 , SU_LMT       INTEGER                 DEFAULT 0   NOT NULL            /* 120 閲覧制限数   */
 , DY_LMT       INTEGER                 DEFAULT 0   NOT NULL            /* 130 閲覧期日     */
 , FGANGO       VARCHAR  (    1 )       DEFAULT '0' NOT NULL            /* 140 暗号化FG     */
 , FGZIP        VARCHAR  (    1 )       DEFAULT '0' NOT NULL            /* 150 圧縮FG       */
 , FILE_NAME    VARCHAR  (  500 )                                       /* 160 ﾌｧｲﾙ名称     */
 , CONTENTS     VARCHAR  ( 4000 )                                       /* 170 内容         */
 , FG_NEW       VARCHAR  (    1 )       DEFAULT '1' NOT NULL            /* 180 最新FG       */
 , SIZE_FILE    INTEGER                 DEFAULT 0   NOT NULL            /* 190 ﾌｧｲﾙｻｲｽﾞ     */
 , DYFILESET    VARCHAR  (   14 )                                       /* 200 ﾌｧｲﾙ登録日時 */
 , USRTOROKU    VARCHAR  (   10 )                                       /* 210 ﾌｧｲﾙ登録者   */
 , SETGUIID     VARCHAR  (   10 )                                       /* 220 登録画面ID   */
 , FGKOSHIN     VARCHAR  (    1 )       DEFAULT '1'                     /* 230 変更許可FG   */
 , FGKOKAI      VARCHAR  (    1 )       DEFAULT '1'                     /* 240 公開許可FG   */
 , SRCHKEY1     VARCHAR  (  500 )                                       /* 250 検索ｷｰ1      */
 , SRCHKEY2     VARCHAR  (  500 )                                       /* 270 検索ｷｰ2      */
 , SRCHKEY3     VARCHAR  (  500 )                                       /* 280 検索ｷｰ3      */
 , SRCHKEY4     VARCHAR  (  500 )                                       /* 290 検索ｷｰ4      */
 , SRCHKEY5     VARCHAR  (  500 )                                       /* 300 検索ｷｰ5      */
 , SRCHKEY6     VARCHAR  (  500 )                                       /* 310 検索ｷｰ6      */
 , SRCHKEY7     VARCHAR  (  500 )                                       /* 320 検索ｷｰ7      */
 , SRCHKEY8     VARCHAR  (  500 )                                       /* 330 検索ｷｰ8      */
 , SRCHKEY9     VARCHAR  (  500 )                                       /* 340 検索ｷｰ9      */
 , SRCHKEY10    VARCHAR  (  500 )                                       /* 350 検索ｷｰ10     */
 , UNIQ         IDENTITY                                                /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR  (    1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR  (   14 )                                       /* 820 登録日時     */
 , PGSET        VARCHAR  (   10 )                                       /* 830 作成PG       */
 , PGPSET       VARCHAR  (   10 )                                       /* 840 作成親PG     */
 , USRSET       VARCHAR  (   10 )                                       /* 850 作成者       */
 , DYUPD        VARCHAR  (   14 )                                       /* 860 更新日時     */
 , PGUPD        VARCHAR  (   10 )                                       /* 870 更新PG       */
 , PGPUPD       VARCHAR  (   10 )                                       /* 880 更新親PG     */
 , USRUPD       VARCHAR  (   10 )                                       /* 890 更新者       */
);
